#ifndef HARKIO_HARKCONFIG_HARKCONFIGFILE_HPP_
#define HARKIO_HARKCONFIG_HARKCONFIGFILE_HPP_

#include <string>
#include <harkio2/harkconfig/Writable.hpp>

/** @file HarkConfigFile.hpp
 * @brief HarkConfigFile class and subclasses definitions.
 */

namespace harkio2
{

class Version;

namespace harkconfig
{

/** @brief HARK config file.
 * Base class for ImpulseResponseListFile, TSPListFile, MicArrayListFile, NoiseLocationFile.
 */
class HarkConfigFile : public Writable
{
public:
    virtual ~HarkConfigFile() {}

    /** @brief Returns the file type identifier.
     * Returns the identifier which this instance actually represents,
     * such as "ImpulseResponseListFile" and "TSPListFile".
     * @return The file type identifier
     */
    virtual std::string GetId() const = 0;

    /** @brief Returns the file version.
     * Returns the version which this instance actually represents.
     * If you call this method from derived class, such as
     * ImpulseResponseListFileX_Y, you will get Version(X, Y).
     * @return The file type version number
     */
    virtual harkio2::Version GetVersion() const = 0;
};

}
}

#endif // HARKIO_HARKCONFIG_HARKCONFIGFILE_HPP_

